import React, { useState, useEffect } from 'react';
import { Modal, Form, Switch, InputNumber, Input, Button, TreeSelect, Space, Select } from 'antd'
import { gettree, GetCouponList } from '../service';
import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons';
const { Option } = Select;
const CreateForm = (props) => {
  const [OrgList, setOrgList] = useState([]);
  // 优惠券列表
  const [couponList, setCouponList] = useState([]);
  const [form] = Form.useForm();
  /**
   * 获取优惠券分页
   */
  const onFetchCouponList = async () => {
    const response = await GetCouponList({
      current: 1,
      pageSize: 999
    });
    if (response.statusCode === 200 && response.data) {
      setCouponList(response.data.data);
    }
  }

  /**
   * 提交表单数据
   * @param {*} data 
   */
  const onFinishForm = (data) => {
    props.onFinish(data);
  }

  const initFormData = () => {
    if (props.values?.couponInfo) {
      const couponArray = JSON.parse(props.values.couponInfo);
      couponArray.forEach(item => {
        item.couponId = item.CouponId;
        item.quantity = item.Quantity;
      });
      form.setFieldsValue({
        ...props.values,
        couponInfos: couponArray
      })
    }
  }

  function initOrgList() {
    gettree().then((r) => {
      inittree(r.data);
      function inittree(datas) {
        for (var i in datas) {
          if (datas[i]['type'] == 2 || datas[i]['type'] == 3) {
            datas[i]['disabled'] = false;
          } else {
            datas[i]['disabled'] = true;
          }

          if (datas[i].children) {
            inittree(datas[i].children);
          }
        }
      }
      setOrgList(r.data);
    });
  }

  //初始化数据
  useEffect(() => {
    initOrgList();
    onFetchCouponList();
    initFormData();
  }, []);

  return <>
    <Modal
      title={props.values.id ? '编辑充值活动' : '新建充值活动'}
      width={500}
      visible={props.createModalVisible}
      footer={null} //底部内容
      onCancel={() => {
        props.onCancel();
      }}
      //关闭时销毁 Modal 里的子元素
      destroyOnClose={true}
    >
      <Form
        preserve={false}
        initialValues={props.values}
        labelCol={{ span: 4 }}
        layout="Horizontal"
        // initialValues={props.values}
        onFinish={onFinishForm}
        form={form}
      >
        <Form.Item name="id" hidden={true}>
          <Input />
        </Form.Item>
        <Form.Item name="storeId" label="选择店铺" rules={[{ required: true, max: 64 }]}>
          <TreeSelect
            style={{ width: '100%' }}
            dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
            treeData={OrgList}
            placeholder="归属门店"
            treeDefaultExpandAll
          />
        </Form.Item>
        <Form.Item name="rechargeMoney" label="充值金额" rules={[{ required: true, max: 64, type: 'money' }]}>
          <InputNumber
            formatter={(value) => `$ ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
            parser={(value) => value.replace(/\$\s?|(,*)/g, '')}
            value={props.values.rechargeMoney}
            stringMode
            style={{ width: '100%' }}
          />
        </Form.Item>

        <Form.Item name="giveMoney" label="赠送金额" rules={[{ required: true, max: 64, type: 'money' }]}>
          <InputNumber
            formatter={(value) => `$ ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
            parser={(value) => value.replace(/\$\s?|(,*)/g, '')}
            style={{ width: '100%' }}
            value={props.values.giveMoney}
            stringMode
          />
        </Form.Item>
        <Form.Item name="recommend" label="是否推荐">
          <Switch checked={props.values.recommend} />
        </Form.Item>
        <Form.List name="couponInfos">
          {(fields, { add, remove }) => (
            <>
              {fields.map((field) => (
                <Space key={field.key} align="baseline">
                  <Form.Item
                    shouldUpdate={true}
                  >
                    {() => (
                      <Form.Item
                        {...field}
                        label="优惠券"
                        name={[field.name, 'couponId']}
                        rules={[
                          {
                            required: true,
                            message: '请选择优惠券',
                          },
                        ]}
                      >
                        <Select
                          style={{
                            width: 200,
                          }}
                        >
                          {couponList.map((item) => (
                            <Option key={item.id} value={item.id}>
                              {item.couponTitle}
                            </Option>
                          ))}
                        </Select>
                      </Form.Item>
                    )}
                  </Form.Item>
                  <Form.Item
                    {...field}
                    label="数量"
                    name={[field.name, 'quantity']}
                    labelCol={{ span: 8 }}
                    rules={[
                      {
                        required: true,
                        message: '请输入优惠券数量！',
                      },
                    ]}
                  >
                    <Input type="number" style={{width: '100px'}} />
                  </Form.Item>

                  <MinusCircleOutlined onClick={() => remove(field.name)} />
                </Space>
              ))}

              <Form.Item>
                <Button type="dashed" onClick={() => add()} block icon={<PlusOutlined />}>
                  选择优惠券
                </Button>
              </Form.Item>
            </>
          )}
        </Form.List>
        <Form.Item>
          <Button type="primary" htmlType="submit" style={{ float: 'right' }}>
            保存
          </Button>
        </Form.Item>
      </Form >
    </Modal>
  </>
}
export default CreateForm;