import { DropboxOutlined, PlusOutlined,UploadOutlined  } from '@ant-design/icons';
import { Button, message, Input, Upload, Modal, Popconfirm } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import CreateForm from './components/CreateForm';
import ActionForm from './components/ActionForm';
import {
  getGoodstechnologypage,
  addgoodstechnology,
  updategoodstechnology,
  deletegoodstechnology,
  GetDicList
} from './services';

//页面 相当于 class
/**
 * 添加节点
 *
 * @param fields
 */
const handleAdd = async (fields) => {
  try {
    await addgoodstechnology(JSON.stringify(fields)).then((r) => {
      if (r.data) {
        message.success('添加成功');
      } else {
        message.error(r.errors);
      }
    });
    return true;
  } catch (error) {
    message.error('添加失败请重试！');
    return false;
  }
};
/**
 * 批量删除节点
 *
 * @param selectedRows
 */
const handleRemove = async (ids) => {
  try {
    deletegoodstechnology(ids).then((r) => {
      if (r.data) {
        message.success('删除成功');
      } else {
        message.error(r.errors);
      }
    });
    return true;
  } catch (error) {
    message.error('删除失败，请重试');
  }
};

const props = {
  beforeUpload: (file) => {
    if (
      file.type !== 'application/vnd.ms-excel' &&
      file.type !== 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
    ) {
      message.error(`${file.name} 不是 exelce 文件`);
    }
    return file.type == 'application/vnd.ms-excel' ||
      file.type == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
      ? true
      : Upload.LIST_IGNORE;
  },
  name: 'file',
  action: '/kitchen/api/goodes/DeviceVersionTemplateImport',
  headers: {
    Authorization:'Bearer  ' + localStorage.getItem('token')
  },
  onChange(info) {
    if (info.file.status !== 'uploading') {
      console.log(info.file, info.fileList);
    }
    if (info.file.status === 'done') {
      message.success(`${info.file.name} file uploaded successfully`);
    } else if (info.file.status === 'error') {
      message.error(`${info.file.name} file upload failed.`);
    }
  }
};

/**
 * 更新节点
 *
 * @param fields
 */

const handleUpdate = async (fields) => {
  try {
    updategoodstechnology(fields).then((r) => {
      if (r.data) {
        message.success('修改成功');
      } else {
        message.error(r.errors);
      }
    });
    return true;
  } catch (error) {
    message.error('修改失败请重试！');
    return false;
  }
};
//页面 相当于 class
const bomtechnology = () => {
  /** 新建/更新窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */
  
  const [actionFormModalVisible, setactionFormModalVisible] = useState(false);
  const [showDetail, setShowDetail] = useState(false);
  //绑定
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  //选中的行
  const [selectedRowsState, setSelectedRows] = useState([]);
  const [DeviceVesionData, setDeviceVesionData] = useState([]);
  /** 国际化配置 */
  const [DictData, setDictData] = useState([]);
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: '规则名称是唯一的 key',
      hideInSearch: true,
      hideInTable: true,
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: '名称',
      dataIndex: 'name',
      valueType: 'textarea',
      ellipsis: true,
      search: true,
    },
    {
      title: '关联外键',
      dataIndex: 'foreignKeyRe',
      valueType: 'textarea',
      ellipsis: true,
      search: true,
    },
    {
      title: '设备类型',
      dataIndex: 'deviceTypeKey',
      valueType: 'textarea',
      ellipsis: true,
      search: true,
    },
    {
      title: '版本',
      dataIndex: 'vesion',
      valueType: 'textarea',
      ellipsis: true,
      search: true,
    },
    {
      title: '状态',
      dataIndex: 'status',
      hideInForm: true,
      search: true,
      valueEnum: {
        0: {
          text: '正常',
          status: 'Processing',
        },
        1: {
          text: '停用',
          status: 'Success',
        },
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'date',
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="state"
          onClick={async () => {
            let a = 0;
            if (record.status == 0) {
              a = 1;
            }
            setCurrentRow((record.status = a));

            await handleUpdate(record).then((r) => {
              if (r) {
                actionRef.current.reload();
              } else {
                message.error('配置失败请重试！');
              }
            });
          }}
        >
          {record.status == 0 ? '停用' : '使用'}
        </a>,
        <a
          key="config"
          onClick={() => {
            handleModalVisible(true);
            setCurrentRow(record);
            actionRef.current?.reloadAndRest?.();
          }}
        >
          更新
        </a>,
        <a
        key="config"
        onClick={() => {
          setactionFormModalVisible(true);
          setCurrentRow(record);
          actionRef.current?.reloadAndRest?.();
        }}
      >
        模型配置
      </a>,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {
            handleRemove([record.id]);
            actionRef.current?.reloadAndRest();
          }}
          onCancel={() => {}}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    },
  ];
  useEffect(() => {
    GetDicList('DeviceClientType').then((r) => {
        var arr = r.data;
        let data = {};
        if (r.succeeded) {
          var list = [];
          arr.forEach((item) => {
            data[item.code] = { text: item.code };
            list.push({
              code: item.code,
              value: item.code,
            });
          });
          //setDicDataAny(data);
          setDictData(list);
        }
      });
  }, [])
  return (
    <PageContainer>
      <ProTable
        headerTitle="工艺"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        columns={columns}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
              setCurrentRow({});
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
            <Button
            key="primary"
            onClick={async  () => {
               
                const link = document.createElement('a');
                link.href = "https://hbl-test-1305371387.cos.ap-chengdu.myqcloud.com//Franchisee/gzaxn@163.com/goods/133458884696092845.xlsx";
                link.click();  
            }}
          >
            <UploadOutlined /> 下载设备版本工艺模板
          </Button>,
           <Upload {...props}>
           <Button icon={<UploadOutlined />}>导入工艺模版</Button>
         </Upload>
        ]}
        //数据绑定
        request={async (params) => {
          var data = [];
          var total = 0;
          await getGoodstechnologypage(params).then((r) => {
            data = r.data.data;
            data.forEach((x) => {
              x.status = x.status.toString();
            });
            total = r.data.total;
          });
          return {
            data: data,
            success: true,
            total: total,
          };
        }}
        // 每行选择点击事件
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      ></ProTable>
      <CreateForm
        onFinish={async (value) => {
          var success = false;
          if (value.id) {
            success = await handleUpdate(value);
          } else {
            success = await handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            if (actionRef.current) {
              actionRef.current.reload();
            }
          }
        }}
        onCancel={() => {
          setCurrentRow(undefined);
          handleModalVisible(false);
        }}
        createModalVisible={createModalVisible}
        values={currentRow || {}}
        dicData={DictData}
      />
      <ActionForm actionFormModalVisible={actionFormModalVisible}
      values={currentRow || {} }
      onCancel={() => {
        setCurrentRow(undefined);
        setactionFormModalVisible(false);
      }}
      />
    </PageContainer>
  );
};

export default bomtechnology;
